==> ejc-invest-impl-3.0.0-20250317.041129-11-sources.jar: com/ejianc/business/budget/mapper/BudgetProjectProMapper.java <==
package com.ejianc.business.budget.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.budget.bean.BudgetProjectProEntity;
import com.ejianc.business.budget.vo.BudgetProjectDetailProVO;
import com.ejianc.business.budget.vo.BudgetProjectDetailReferenProVO;
import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 项目预算主实体
 * 
 * @author generator
 * 
 */
@Mapper
public interface BudgetProjectProMapper extends BaseCrudMapper<BudgetProjectProEntity> {

    List<BudgetProjectDetailReferenProVO> queryDetailList(Page<BudgetProjectDetailReferenProVO> page, @Param(Constants.WRAPPER) QueryWrapper wrapper, @Param("projectId") Long projectId, @Param("costType") String costType);

    List<BudgetProjectDetailReferenProVO> queryOtherDetailList(Page<BudgetProjectDetailReferenProVO> page,@Param(Constants.WRAPPER) QueryWrapper wrapper,@Param("projectId") Long projectId,@Param("costType") String costType);

    List<BudgetProjectDetailProVO> querySubDetailList(Page<BudgetProjectDetailProVO> page,@Param(Constants.WRAPPER) QueryWrapper wrapper,@Param("projectId") Long projectId,@Param("costType") String costType);

    List<BudgetProjectDetailProVO> queryOnlySuject(Long projectId, Integer costType, Set<Long> subjectIds);

    List<BudgetProjectDetailProVO> getBudgetProjectDetailProDataAndSum(Long projectId);

    Map<String, BigDecimal> getProOutMny(Long projectId, Long id, String billTypeCode);
}

==> ejc-invest-impl-3.0.0-20250414.073545-34-sources.jar: com/ejianc/business/budget/mapper/BudgetProjectProMapper.java <==
package com.ejianc.business.budget.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.budget.bean.BudgetProjectProEntity;
import com.ejianc.business.budget.vo.BudgetProjectDetailProVO;
import com.ejianc.business.budget.vo.BudgetProjectDetailReferenProVO;
import com.ejianc.business.budget.vo.DynamicsCostVO;
import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 项目预算主实体
 * 
 * @author generator
 * 
 */
@Mapper
public interface BudgetProjectProMapper extends BaseCrudMapper<BudgetProjectProEntity> {

    List<BudgetProjectDetailReferenProVO> queryDetailList(Page<BudgetProjectDetailReferenProVO> page, @Param(Constants.WRAPPER) QueryWrapper wrapper, @Param("projectId") Long projectId, @Param("costType") String costType);

    List<BudgetProjectDetailReferenProVO> queryOtherDetailList(Page<BudgetProjectDetailReferenProVO> page,@Param(Constants.WRAPPER) QueryWrapper wrapper,@Param("projectId") Long projectId,@Param("costType") String costType);

    List<BudgetProjectDetailProVO> querySubDetailList(Page<BudgetProjectDetailProVO> page,@Param(Constants.WRAPPER) QueryWrapper wrapper,@Param("projectId") Long projectId,@Param("costType") String costType);

    List<BudgetProjectDetailProVO> queryOnlySuject(Long projectId, Integer costType, Set<Long> subjectIds);

    List<BudgetProjectDetailProVO> getBudgetProjectDetailProDataAndSum(Long projectId);

    Map<String, BigDecimal> getProOutMny(Long projectId, Long id, String billTypeCode);

    List<DynamicsCostVO> querySubjectTree(@Param("projectId") Long projectId, @Param("budgetId") Long budgetId);

    List<DynamicsCostVO> queryDynamicsCost(@Param("projectId") Long projectId, @Param("budgetId") Long budgetId);
}
